@@ -59,10 +59,12 @@ def ask_yn(msg: str, default: bool = False) -> bool:
 
 
 def ask_Yn(msg: str) -> bool:
+    msg = f"{msg} (Y/n): "
     return ask_yn(msg, True)
 
 
 def ask_yN(msg: str) -> bool:
+    msg = f"{msg} (y/N): "
     return ask_yn(msg, False)
 
 
@@ -72,6 +74,7 @@ def ask_no_empty(msg: str) -> str:
 
 
 def confirm_proceed() -> None:
-    if not ask_yN("Do you want to proceed? (y/N): "):
+    if not ask_Yn("Are you sure? (Y/n): "):
         print("Canceled.")
         sys.exit(0)
+    print()
